@@ -35,7 +35,7 @@ import unipath
 from unipath import pathof
 import unicodedata
 
-_launcher_version=20190716
+_launcher_version=20190801
 
 _PKG_VER = re.compile(r'''<\s*package[^>]*version\s*=\s*["']([^'"]*)['"][^>]*>''',re.IGNORECASE)
 
@@ -587,13 +587,18 @@ class Wrapper(object):
             mime = ext_mime_map.get(ext, None)
         if mime is None:
             raise WrapperException("Mime Type Missing")
+        if mime == "application/x-dtbncx+xml" and self.epub_version.startswith("2"):
+            raise WrapperException('Can not add or remove an ncx under epub2')
         if mime.startswith("audio"):
-            base = 'Audio'
+            base = "Audio"
         elif mime.startswith("video"):
             base = "Video"
         else:
             base = mime_base_map.get(mime,'Misc')
-        href = base + "/" + basename
+        if base == "":
+            href = basename
+        else:
+            href = base + "/" + basename
         if uniqueid in self.id_to_href:
             raise WrapperException('Manifest Id is not unique')
         if href in self.href_to_id:
@@ -627,6 +632,8 @@ class Wrapper(object):
         filepath = self.id_to_filepath.get(id, None)
         if id is None:
             raise WrapperException('Id does not exist in manifest')
+        if self.epub_version.startswith("2") and id == self.gettocid():
+            raise WrapperException('Can not add or remove an ncx under epub2')
         add_to_deleted = True
         # if file was added or modified, delete file from outdir
         if id in self.added or id in self.modified:
